Rename SPARC V8 target to be the LLVM SPARC target.


git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@25985 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/Target/Sparc/SparcSubtarget.h b/lib/Target/Sparc/SparcSubtarget.h
index 615d3d4..59da95a 100644
--- a/lib/Target/Sparc/SparcSubtarget.h
+++ b/lib/Target/Sparc/SparcSubtarget.h
@@ -1,4 +1,4 @@
 //=====-- SparcV8Subtarget.h - Define Subtarget for the SPARC -*- C++ -*--====//
 //
 //                     The LLVM Compiler Infrastructure
 //
@@ -20,12 +20,12 @@
 namespace llvm {
   class Module;
   
-class SparcV8Subtarget : public TargetSubtarget {
+class SparcSubtarget : public TargetSubtarget {
   bool IsV9;
   bool V8DeprecatedInsts;
   bool IsVIS;
 public:
-  SparcV8Subtarget(const Module &M, const std::string &FS);
+  SparcSubtarget(const Module &M, const std::string &FS);
 
   bool isV9() const { return IsV9; }
   bool isVIS() const { return IsVIS; }
@@ -1,4 +1,4 @@
-//=====-- SparcV8Subtarget.h - Define Subtarget for the SPARC -*- C++ -*--====//
+//=====-- SparcSubtarget.h - Define Subtarget for the SPARC ----*- C++ -*-====//
 //
 //                     The LLVM Compiler Infrastructure